==> Dominance_0.9.9.tar.gz: Dominance/man/sociogram.Rd <==
\name{Sociogram}
\alias{Sociogram}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{
Social Network Graphs
}
\description{
computes social network graphs with igraph
}
\usage{
Sociogram(data, bits, ...)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{data}{
either a data.frame f.e imported from a data sheet containing
 
                                "Name","item.number"
                                
                                "action.from.","action.to","kind.of.action"
                                
                                "name.of.action","action.number","classification","weighting"
                                

                                 
or only "action.from.","action.to","kind.of.action"if exists actions and items


 
data: with "action.from.","action.to","kind.of.action"

items  with "Name","item.number" 
}
  \item{bits}{
as sting where each enabled action is set to 1 and each disabled action is set to 0
}
  \item{...}{
 Postscript: FALSE (default) or path to PS output file

  soziogram_layout: layout.auto,layout.random,layout.circle,layout.sphere,layout.fruchterman.reingold,layout.kamada.kawai,layout.spring,layout.reingold.tilford,layout.fruchterman.reingold.grid,layout.lgl,layout.graphopt,layout.svd,layout.norm
 
 curved: how much the lines between the nodes ar curved 0 ist stright, default is 0.2
 
 scal_value: the multiplicator of the nodes, default: 1/3
 
 linesize_add: value to add to the linesize (helpful for a graph with thin lines. default 0
 
 log: log2 size of linewitdh,  default= false
 
 canvas.width: default 1000
 
 canvas.height: default 800
 
 tkplot: interactiv tkplot, default = true
 
 }
}
%% \details{
%%  ~~ If necessary, more details than the description above ~~
%% }
\value{

  \item{sociogram}{ the igraph object}
  \item{counts_circles }{the count of cirles}
  \item{count_interactions }{the count of interactions}
  \item{line_size}{the used linesize}
  \item{counts_circles }{vector of min and max line size}
  the last for are helpful to change circle size and linewidth

}
%% \references{
%% ~put references to the literature/web site here ~
%% }
\author{
Knut Krueger
}
%% \note{
%%  ~~further notes~~
%% }

%% ~Make other sections like Warning with \section{Warning }{....} ~

%% \seealso{
%% ~~objects to See Also as \code{\link{help}}, ~~~
%% }
\examples{


## you can eihter use:
data=data.frame   ("action.from"=c(1,4,2,3,4,3,4,3,4,3,4,3,4,3,4),
                   "action.to"=c(4,1,1,4,3,4,3,4,3,4,3,4,3,4,3),
                   "kind.of.action"= c(4,1,1,4,3,4,3,4,3,4,3,4,3,4,3),stringsAsFactors=FALSE)
items= data.frame ("Name"=c("item1","item2","item3","item4","item5","item6") ,
                   "item.number"=c(1:6),stringsAsFactors=FALSE)
actions=data.frame("name.of.action"= c("leading","following","approach","bite","threat to bite", "kick","threat to kick", "chase","retreat"),
                   "action.number"=c(1:9),
                   "classification"=c(1,2,1,1,1,1,1,1,2) ,
                   "weighting"=c(1,-1,1,1,1,1,1,1,-1),stringsAsFactors=FALSE)
## all  encounters  without leading and following
bytes= "001111111"  
Sociogram(data,items=items,actions=actions,bytes)
## mor you can use a complete f.e Excel sheet
## you can save this data as basic excel sheet to work with
data(data_Network_1)
## set 1 for action you want to show
bytes= "00111111111000000000"    
Sociogram(data_Network_1,bytes)


}
% Add one or more standard keywords, see file 'KEYWORDS' in the
% R documentation directory.
\keyword{ ~kwd1 }
\keyword{ ~kwd2 }% __ONLY ONE__ keyword per line

==> Dominance_0.9.11.tar.gz: Dominance/man/sociogram.Rd <==
\name{Sociogram}
\alias{Sociogram}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{
Social Network Graphs
}
\description{
computes social network graphs with igraph
}
\usage{
Sociogram(data, bits, ...)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{data}{
either a data.frame f.e imported from a data sheet containing
 
                                "Name","item.number"
                                
                                "action.from.","action.to","kind.of.action"
                                
                                "name.of.action","action.number","classification","weighting"
                                

                                 
or only "action.from.","action.to","kind.of.action"if exists actions and items


 
data: with "action.from.","action.to","kind.of.action"

items  with "Name","item.number" 
}
  \item{bits}{
as sting where each enabled action is set to 1 and each disabled action is set to 0
}
  \item{...}{
 Postscript: FALSE (default) or path to PS output file

  soziogram_layout: layout.auto,layout.random,layout.circle,layout.sphere,layout.fruchterman.reingold,layout.kamada.kawai,layout.spring,layout.reingold.tilford,layout.fruchterman.reingold.grid,layout.lgl,layout.graphopt,layout.svd,layout.norm
 
 curved: how much the lines between the nodes ar curved 0 ist stright, default is 0.2
 
 scal_value: the multiplicator of the nodes, default: 1/3
 
 linesize_add: value to add to the linesize (helpful for a graph with thin lines. default 0
 
 log: log2 size of linewitdh,  default= false
 
 canvas.width: default 1000
 
 canvas.height: default 800
 
 tkplot: interactiv tkplot, default = true
 
 }
}
%% \details{
%%  ~~ If necessary, more details than the description above ~~
%% }
\value{

  \item{sociogram}{ the igraph object}
  \item{counts_circles }{the count of cirles}
  \item{count_interactions }{the count of interactions}
  \item{line_size}{the used linesize}
  \item{counts_circles }{vector of min and max line size}
  the last for are helpful to change circle size and linewidth

}
%% \references{
%% ~put references to the literature/web site here ~
%% }
\author{
Knut Krueger
}
%% \note{
%%  ~~further notes~~
%% }

%% ~Make other sections like Warning with \section{Warning }{....} ~

%% \seealso{
%% ~~objects to See Also as \code{\link{help}}, ~~~
%% }
\examples{


## you can eihter use:
data=data.frame   ("action.from"=c(1,4,2,3,4,3,4,3,4,3,4,3,4,3,4),
                   "action.to"=c(4,1,1,4,3,4,3,4,3,4,3,4,3,4,3),
                   "kind.of.action"= c(4,1,1,4,3,4,3,4,3,4,3,4,3,4,3),stringsAsFactors=FALSE)
items= data.frame ("Name"=c("item1","item2","item3","item4","item5","item6") ,
                   "item.number"=c(1:6),stringsAsFactors=FALSE)
actions=data.frame("name.of.action"= c("leading","following","approach","bite","threat to bite",
                   "kick","threat to kick", "chase","retreat"),
                   "action.number"=c(1:9),
                   "classification"=c(1,2,1,1,1,1,1,1,2) ,
                   "weighting"=c(1,-1,1,1,1,1,1,1,-1),stringsAsFactors=FALSE)
## all  encounters  without leading and following
bytes= "001111111"  
Sociogram(data,items=items,actions=actions,bytes)
## mor you can use a complete f.e Excel sheet
## you can save this data as basic excel sheet to work with
data(data_Network_1)
## set 1 for action you want to show
bytes= "00111111111000000000"    
Sociogram(data_Network_1,bytes)


}
% Add one or more standard keywords, see file 'KEYWORDS' in the
% R documentation directory.
\keyword{ ~kwd1 }
\keyword{ ~kwd2 }% __ONLY ONE__ keyword per line
